@@ -8,11 +8,12 @@ from pyiron_base.generic.hdfio import FileHDFio, ProjectHDFio
 from pyiron_base.generic.inputlist import InputList
 from pyiron_base.generic.parameters import GenericParameters
 from pyiron_base.generic.template import PyironObject
-from pyiron_base.generic.util import deprecate, deprecate_soon
+from pyiron_base.generic.util import deprecate, deprecate_soon, ImportAlarm
 from pyiron_base.job.executable import Executable
 from pyiron_base.job.external import Notebook
 from pyiron_base.job.generic import GenericJob
 from pyiron_base.job.interactive import InteractiveBase
+from pyiron_base.job.interactivewrapper import InteractiveWrapper
 from pyiron_base.job.jobstatus import JobStatus, job_status_successful_lst, job_status_finished_lst, job_status_lst
 from pyiron_base.job.jobtype import JOB_CLASS_DICT, JobType, JobTypeChoice
 from pyiron_base.job.template import TemplateJob, PythonTemplateJob
